"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const builtinModules = require("builtin-modules");
const react_to_typescript_definitions_1 = require("react-to-typescript-definitions");
const rollup_1 = require("rollup");
const babel = require("rollup-plugin-babel");
const commonjs = require("rollup-plugin-commonjs");
const json = require("rollup-plugin-json");
const resolve = require("rollup-plugin-node-resolve");
const debug_1 = require("./debug");
const rollup_plugin_replace_with_empty_module_1 = require("./rollup-plugin-replace-with-empty-module");
const defaultBundleOptions = {
    external: builtinModules.concat(['react', 'prop-types']),
    replaceWithEmptyModulePatterns: ['**/*.css'],
};
async function generateBundleCode(input, options) {
    options = Object.assign({}, defaultBundleOptions, options);
    const bundle = await rollup_1.rollup({
        input,
        external: options.external,
        plugins: [
            rollup_plugin_replace_with_empty_module_1.replaceWithEmptyModule(options.replaceWithEmptyModulePatterns),
            resolve({
                extensions: ['.js', '.jsx'],
                jsnext: true,
                preferBuiltins: true,
            }),
            json(),
            babel({
                presets: [
                    [
                        require.resolve('babel-preset-env'),
                        { modules: false, targets: { node: '6.5' } },
                    ],
                    require.resolve('babel-preset-react'),
                    require.resolve('babel-preset-stage-2'),
                ],
                plugins: ['external-helpers'],
                externalHelpers: true,
            }),
            commonjs(),
        ],
    });
    const { code } = await bundle.generate({ format: 'es' });
    debug_1.debug(code);
    return code;
}
async function generateTypings(moduleName, input, options) {
    const code = await generateBundleCode(input, options);
    return react_to_typescript_definitions_1.generateFromSource(moduleName, code);
}
exports.generateTypings = generateTypings;
//# sourceMappingURL=generate.js.map